@@ -34,12 +34,12 @@
 //
 //-*****************************************************************************
 
-#ifndef _Alembic_Util_Config_h_
-#define _Alembic_Util_Config_h_
+#ifndef Alembic_Util_Config_h
+#define Alembic_Util_Config_h
 
 // Reserve 2 digits for patch number, 2 digits for the minor number and the rest
 // for the major.
-#define ALEMBIC_LIBRARY_VERSION 1 * 10000 + 7 * 100 + 8
+#define ALEMBIC_LIBRARY_VERSION 1 * 10000 + 7 * 100 + 9
 
 /* #undef ALEMBIC_WITH_HDF5 */
 
